@@ -14,9 +14,12 @@ class apiBase:
         self.sleep = sleep
 
         self.default_columns = ['high', 'volume', 'low', 'close', 'open']
+        self.symbol_dict = None
         self.start = None
         self.limit = None
 
+        self.suppress_warning = False
+
     def get(self, *args, **kwargs):
         raise NotImplementedError
 
@@ -28,6 +31,15 @@ class apiBase:
         else:
             raise Exception('Only hours supportted right now')
 
+    def symbol_check(self, symbol):
+        if symbol in self.symbol_dict:
+            symbol = self.symbol_dict[symbol]
+        else:
+            if not self.suppress_warning:
+                print('Warning: Not using a supported symbol, not every module might work.')
+                self.suppress_warning = True
+        return symbol
+
     def response_handler(self, address, params, timeout=60):
         r = requests.get(address, params=params, timeout=timeout)
 
