@@ -21,6 +21,16 @@ class binanceBase(apiBase):
         self.limit = 1000
         self.default_columns = ['open', 'high', 'low', 'close', 'volume', 'quote_asset_vol',
                             'number_of_trades', 'taker_base_asset_vol', 'taker_quote_asset_vol']
+
+        self.symbol_dict = {
+            'btcusd': 'BTCUSDT',
+            'ethusd': 'ETHUSDT',
+            'ethbtc': 'ETHBTC',
+            'ltcusd': 'LTCUSDT',
+            'bchusd': 'BCHUSDT',
+            'eosusd': 'EOSUSDT',
+            'xrpusd': 'XRPUSDT',
+        }
     
     def get(self,
             limit: int = None,
@@ -34,13 +44,15 @@ class binanceBase(apiBase):
             return_r: bool = False,
             ):
 
-        start, end, out_of_range = self.calc_start(limit, start, end)
-        if out_of_range:
-            return self.get_hist(start=start, end=end)
-        
         address = address or self.address
         address = self.base_address + address
-        symbol = symbol or 'BTCUSDT'        
+        symbol = symbol or 'btcusd'        
+        
+        start, end, out_of_range = self.calc_start(limit, start, end)
+        if out_of_range:
+            return self.get_hist(symbol=symbol, start=start, end=end)
+
+        symbol = self.symbol_check(symbol)  # had to give raw symbol above, this has to be after     
         
         if query is None:
             limit = self.limit if limit is None else limit
@@ -51,6 +63,8 @@ class binanceBase(apiBase):
         r = requests.get(address, params=query)
 
         result = r.json()
+        if len(result) == 0:
+            return None
 
         df = pd.DataFrame(result, columns=['open_time', 'open', 'high', 'low', 'close', 'volume', 'close_time', 'quote_asset_vol',
                                     'number_of_trades', 'taker_base_asset_vol', 'taker_quote_asset_vol', 'ignore'])
@@ -74,4 +88,7 @@ class binanceBase(apiBase):
         return super(binanceBase, self).get_hist(
             *args, **kwargs
         )
+
+    def _start_check(self, address, symbol):
+        raise Exception('Cant sort oldest item')
     
