@@ -6,6 +6,7 @@ import pandas as pd
 from tradingfeatures import apiBase
 from tradingfeatures.apis.binance.base import binanceBase
 from tradingfeatures.apis.binance.funding import binanceFunding
+from tradingfeatures.apis.binance.order_book import binanceOrderBook
 
 
 class binance(binanceBase):
@@ -14,6 +15,7 @@ class binance(binanceBase):
         super(binance, self).__init__()
 
         self.funding = binanceFunding()
+        self.orderbook = binanceOrderBook()
 
     def update(self, path, update_all=False, *args, **kwargs):        
         if update_all:
